@@ -37,8 +37,10 @@ sub Mojo::Webqq::Model::_get_group_info {
     #retcode等于0说明包含完整的ginfo和minfo
     if(exists $json->{result}{minfo} and ref $json->{result}{minfo} eq "ARRAY"){
         my %cards;
-        for  (@{ $json->{result}{cards} }){
-            $cards{$_->{muin}} = $_->{card};
+        if(ref $json->{result}{cards} eq "ARRAY" or @{ $json->{result}{cards} }!=0){
+            for  (@{ $json->{result}{cards} }){
+                $cards{$_->{muin}} = $_->{card};
+            }
         }
         my %state;
         for(@{ $json->{result}{stats} }){
@@ -46,7 +48,7 @@ sub Mojo::Webqq::Model::_get_group_info {
             $state{$_->{uin}}{state} = $self->code2state($_->{'stat'});
         }
         for my $m(@{ $json->{result}{minfo} }){
-            $m->{card} = exists $cards{$m->{uin}}?$cards{$m->{uin}} : undef; 
+            $m->{card} = $cards{$m->{uin}} if exists $cards{$m->{uin}};
             if(exists $state{$m->{uin}}){
                 $m->{state} = $state{$m->{uin}}{state};
                 $m->{client_type} = $state{$m->{uin}}{client_type};
